@@ -13,7 +13,7 @@
 //! use condow_rusoto::config::Config;
 //!
 //! # async {
-//! let client = S3ClientWrapper::new(Default::default());
+//! let client = S3ClientWrapper::new(Region::default());
 //! let condow = client.condow(Config::default()).unwrap();
 //!
 //! let location = Bucket::new("my_bucket").object("my_object");
@@ -30,10 +30,11 @@ use std::{
 
 use anyhow::Error as AnyError;
 use futures::{future::BoxFuture, stream::TryStreamExt};
-use rusoto_core::{Region, RusotoError};
-use rusoto_s3::{
-    GetObjectError, GetObjectRequest, HeadObjectError, HeadObjectRequest, S3Client, S3,
-};
+use rusoto_core::RusotoError;
+use rusoto_s3::{GetObjectError, GetObjectRequest, HeadObjectError, HeadObjectRequest, S3};
+
+pub use rusoto_core::Region;
+pub use rusoto_s3::S3Client;
 
 use condow_core::{
     condow_client::*,
@@ -190,7 +191,7 @@ impl<C: S3 + Clone + Send + Sync + 'static> S3ClientWrapper<C> {
 impl<C: S3 + Clone + Send + Sync + 'static> CondowClient for S3ClientWrapper<C> {
     type Location = S3Location;
 
-    fn get_size(&self, location: Self::Location) -> BoxFuture<'static, Result<usize, CondowError>> {
+    fn get_size(&self, location: Self::Location) -> BoxFuture<'static, Result<u64, CondowError>> {
         let client = self.0.clone();
         let f = async move {
             let (bucket, object_key) = location.into_inner();
@@ -206,7 +207,7 @@ impl<C: S3 + Clone + Send + Sync + 'static> CondowClient for S3ClientWrapper<C>
                 .map_err(head_obj_err_to_get_size_err)?;
 
             if let Some(size) = response.content_length {
-                Ok(size as usize)
+                Ok(size as u64)
             } else {
                 Err(CondowError::new_other("response had no content length"))
             }
